==> sawmill6.4b3_crypt_src.tar.gz: sawmill-6.4b3/Sbfc9cb0c7c2fe6f4e17de2219c571a09.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// then compilation!



















































 
#include "Sbb7934b786bf92b60599d19b63c794ae.h"

#include "Sbfc9cb0c7c2fe6f4e17de2219c571a09.h"

#include "S02018c21aae4cfd793a8f80f191dec71.h"

#include "S18fff9cb5ec66ea1b3998c0c6f504bdd.h"

#include "Se50f3b1f9b0c326eb12cf99841796fa8.h"

#include "Sa7a50d44af9bffbc03a233a0f926ab33.h"

#include "S34ddd2a7515eccb177b2b41c0576524a.h"

#include "S081ab28a1d97078d41502685d8d23339.h"

#include "Scd1bac794b4941db69a52b57b6ec5f9f.h"

#include "S21d6f40cfb511982e4424e0e250a9557.h"

#include "Sda690b4f1f86a80d09e2b79331302d1f.h"

#include "S502c2d5425ba2c329e58f02e0bf84d5e.h"

#include "Sd72426bef53f59fc97b1772c0f3bf34a.h"

#include "Sfffef868da20c3f5623f11331ac9a581.h"

#include "Sfd40bde7becba15faa6c7faab35e20f0.h"

#include "S4535b1598f7cc738f3c5ab654f23ce06.h"

#include "Sd2dfda25a352b6989f06979d5dca20ff.h"

#include "S5013dc63aece5960aaf85662d6e4defb.h"

#include "Scde0993c6a1124d8ed406bc1a2294738.h"

#include "S3d25fa2cec486988552e0a9ce1a0cb49.h"

#include "S3d52b4397df4d4d0e426da5d85159dbf.h"
 Se812b5a98988bad1d5b8df118cb6cc7f::Se812b5a98988bad1d5b8df118cb6cc7f(Sa374ae40bab87d51f64df15ce1e0bd84 
&S908ea47162d020873e19f62a8278d2d0, S7a8c30ba69067011071ba14cc1b4a63d &S3ecf2642759a04bd3616642bd56bed59) 
: S1d8d5e912302108b5e88c3e77fcad378(S908ea47162d020873e19f62a8278d2d0), S95cc64dd2825f9df13ec4ad683ecf339(S3ecf2642759a04bd3616642bd56bed59) 
{ Sf9fbc004dd2b46f967cbb884ef26a5f1 = 0; Sea0f20f4ee0b8138296f254b6166a9e2 = NULL; S2597f87d2eaac307fffcae4a7696f5e1 
= 0;   Sc2cdb780090f037942c0cc62899c60dd = false; S90c6813d8aa86264da47e54bfbca12b9 = false; S70efd95bbd5a1637e2b2b03545bc7c97 
= 0; Sd81bd76541d72dcc4624a9f668ed831a = -1; Sa3ef522750bb6cfebb259b70bc491252 = -1; Saf34297eba0410328ecf05680c3973fb 
= false; S71e0656cf70f1e0f42713632961f2e83 = 0; S4e2d4ef7375cc680e7d4a5218cb24910 = 0; Sf33b7605ce39a3959a0a0faafa993648 
= false; S5c2b43ac72b401de77771f3d1c229239 = NULL; Sc0ef64f649a3fb31698c0e34e821ca31 = -1; S611a0faa7adb65cbd3d0744c6b2c0a3d 
= NULL; Se4060fc9e6cb63b56cee53c62831fc9b = NULL; Sc4063383a2f1d9cb2dafa0dfae340d83 = NULL; S893154f4ff2478a68c43298003262505 
= false; S42d8701cce0ca1f51d8de5a678eb2261 = 0; S84a149ab6260fd1dba7b42922161cf76 = false; S53e601e276f9f775fc63e5c2ee651d53 
= 0; if (Sa4020546e22fc3be5584817b8fb0246a == NULL) { Sa4020546e22fc3be5584817b8fb0246a = this; Sfcc38fa2214c7dad94042741191c53b3 
= new S18fff9cb5ec66ea1b3998c0c6f504bdd(Se812b5a98988bad1d5b8df118cb6cc7f *); } else { ((S18fff9cb5ec66ea1b3998c0c6f504bdd(Se812b5a98988bad1d5b8df118cb6cc7f 
*) *) Sa4020546e22fc3be5584817b8fb0246a->Sfcc38fa2214c7dad94042741191c53b3)->push_back(this); } S19e7bc76fe6637a0a36ff6bb2c957096 
= NULL; S8d8450e5a0709dfcc6a7dcc77e0b6e4e = NULL; S092302eec8db684d8a43e539e32a52b1 = 0; S7221f6f7a9cab8b731d91ea78e90076f 
= 0; 
#if defined(macintosh)
 Sebfc0bf878d1f1386b9b4c376187faff = new ostringstream(); 
#else
 S1d765418a1157e3335b9e0c1cbe13bec = new Sf3f2f04ccb90d699288e8cb86ada5e67(cout, *this); Sebfc0bf878d1f1386b9b4c376187faff 
= new S1356d0666866080ee569a8007f7465e0(S1d765418a1157e3335b9e0c1cbe13bec); 
#endif
 
#if defined(macintosh) || defined(HAVE_SSTREAM)
 S6023548ba505b16120eba8594d6d354c = new ostringstream(); 
#else
 S82302248d41b4cf5ef692a52b1010298 = (char *) Sb55824cd22e362581a8a09954133e17b(10000); S6023548ba505b16120eba8594d6d354c 
= new S2d587388d84e669166259e637229a736(S82302248d41b4cf5ef692a52b1010298, 9999); 
#endif
 S279361af4d5ba006aa8688d7736f51f9 = NULL; Scb5e100e5a9a3e7f6d1fd97512215282 = false; S81b63b9d54b303edeaf9765a6915ee13 
= false; S6b2ded51d81a4403d8a4bd25fa1e57ee = false; S40a9622db5a27260c4d5e8f1d354958a = new S18fff9cb5ec66ea1b3998c0c6f504bdd(S7bc81a7dfa0975e3e219c94262b1af9b); 
S607e7372580620c5a884262f971fe86a = new Se50f3b1f9b0c326eb12cf99841796fa8(S82fe905a33b09fbebffca79d483bcd10); 
S154a5d876ee73f9b72430feb6abcf728.Sce5e7ecaa34619ce3cd0f11abbe32bde(*Sa4020546e22fc3be5584817b8fb0246a); 
S0e2413620f3009160a31c65634019d56 = S51a60bde560fadde5d0eb57d9f19c0b1; S51a60bde560fadde5d0eb57d9f19c0b1++; 
S154a5d876ee73f9b72430feb6abcf728.Sb8e7b465df7c5979dc731d06e84ce2cf(*Sa4020546e22fc3be5584817b8fb0246a); 
Sd30ed9ead03f1ac95b8affa1956127ed = NULL; S53e601e276f9f775fc63e5c2ee651d53 = 0; Se1156150b1f690c8f2e2cababc4669a8 
= 0; S284bd53fbfb57ba76bac587c3cf1cd0c = 0; S96e6199a1dfa62795bf64060320f0301 = 0; Sfc77f9ae4de2e002f5b72de5dfa577a0(*this); 
Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179 = *this; S2b91dc4462409a9f0466da680eeadb23 
= 50000; Saf6c0c3c714d1f5ab0d299b2cbf50060(Sf1c587725d1d3d625ed5aeb21490ad64 = (char *) S69d014b769e6f390ab59e42ff5dc9571(S2b91dc4462409a9f0466da680eeadb23, 
"initializing token buffer"));   for (int S865c0c0b4ab0e063e5caa3387c1a8741 = 0; S865c0c0b4ab0e063e5caa3387c1a8741 
< 20; S865c0c0b4ab0e063e5caa3387c1a8741++) Sf1c587725d1d3d625ed5aeb21490ad64[S865c0c0b4ab0e063e5caa3387c1a8741] 
= '0'; S3bd31e1db9c41752857ea3dc8b544da5 = NULL; S45bb047ee77be91f951755654fd1cf64 = 0; S490793d90b9f673ca43c5112b6192d9f 
= NULL; Sda690b4f1f86a80d09e2b79331302d1f = NULL; S70ffd93d669ae5f2d9833b3fd696a6bf = new S18fff9cb5ec66ea1b3998c0c6f504bdd(S67d8289f693b177f2a17a6a10106446e); 
S63f7a20c869ab49b1256d73134c51bd8 = NULL; Se9594a2849d3fbc85b7e13386d03c748 = 0; Sa292896a8834f680d0d7910415cfe6aa 
= 0; Sc99faa22803997c264dbf7ec274f626d = 0; S6edff6f9acd6531aba7bf7f6bcf4ebc6 = 0; S6f49c06ecf096f650296b2f597ad7b9d 
= NULL; Sd6c9f1d753edb49ab3b2ce89228f859d = NULL; Sca788bb10eb1084eeb70fe3f9f41ac96 = NULL; S5b17d3bd4a598d71b357f5aba0e56a69 
= 0; Sb3ed21678a76749fa2af40ab56453ac6 = NULL; Se255569260fe9e8f5f75e5f36f1c8244 = false; S700633a1b0f65fa8456a18bd6053193c 
= false; Sb814a6cb84002cd6a8b2ae1c5d3e095b = false; Sa513a681cb9ab5c94d50cd28d932b51c = false; }  Se812b5a98988bad1d5b8df118cb6cc7f::~Se812b5a98988bad1d5b8df118cb6cc7f(void) 
{ if (Sc4063383a2f1d9cb2dafa0dfae340d83) { Sc4063383a2f1d9cb2dafa0dfae340d83->S0f42007614120ad55ee822b263a2982b(*this); 
delete(Sc4063383a2f1d9cb2dafa0dfae340d83); } if (Se4060fc9e6cb63b56cee53c62831fc9b) delete(Se4060fc9e6cb63b56cee53c62831fc9b); 
delete(Sea0f20f4ee0b8138296f254b6166a9e2); S8542634d1f0eb6829badb2e1f5d42138(Sb3ed21678a76749fa2af40ab56453ac6); 
for (S18fff9cb5ec66ea1b3998c0c6f504bdd(Se812b5a98988bad1d5b8df118cb6cc7f *)::iterator Sd895ed90bab5a86173ead3a829e26d10 
= ((S18fff9cb5ec66ea1b3998c0c6f504bdd(Se812b5a98988bad1d5b8df118cb6cc7f *) *) Sa4020546e22fc3be5584817b8fb0246a->Sfcc38fa2214c7dad94042741191c53b3)->begin(); 
Sd895ed90bab5a86173ead3a829e26d10 != ((S18fff9cb5ec66ea1b3998c0c6f504bdd(Se812b5a98988bad1d5b8df118cb6cc7f 
*) *) Sa4020546e22fc3be5584817b8fb0246a->Sfcc38fa2214c7dad94042741191c53b3)->end(); Sd895ed90bab5a86173ead3a829e26d10++) 
{ if (*Sd895ed90bab5a86173ead3a829e26d10 == this) { ((S18fff9cb5ec66ea1b3998c0c6f504bdd(Se812b5a98988bad1d5b8df118cb6cc7f 
*) *) Sa4020546e22fc3be5584817b8fb0246a->Sfcc38fa2214c7dad94042741191c53b3)->erase(Sd895ed90bab5a86173ead3a829e26d10); 
break; } } S8542634d1f0eb6829badb2e1f5d42138(S8d8450e5a0709dfcc6a7dcc77e0b6e4e); for (unsigned long 
S2fbe9ae4fdee1fc17b970499d596fd7b = 0; (long) S2fbe9ae4fdee1fc17b970499d596fd7b < Sc0ef64f649a3fb31698c0e34e821ca31 
+ 1; S2fbe9ae4fdee1fc17b970499d596fd7b ++ ) { S88c189a42c87aa49d667fc8ab76bc323(S5c2b43ac72b401de77771f3d1c229239[S2fbe9ae4fdee1fc17b970499d596fd7b]); 
} Sc0ef64f649a3fb31698c0e34e821ca31 = 0; S88c189a42c87aa49d667fc8ab76bc323(S5c2b43ac72b401de77771f3d1c229239); 
S88c189a42c87aa49d667fc8ab76bc323(S611a0faa7adb65cbd3d0744c6b2c0a3d); delete(Sd6c9f1d753edb49ab3b2ce89228f859d); 
if (S6f49c06ecf096f650296b2f597ad7b9d) delete[] (regmatch_t *) S6f49c06ecf096f650296b2f597ad7b9d; S99641eea54137181f34c9f030edd808e(*this); 
delete((S18fff9cb5ec66ea1b3998c0c6f504bdd(S7bc81a7dfa0975e3e219c94262b1af9b) *) S40a9622db5a27260c4d5e8f1d354958a); 
delete((Se50f3b1f9b0c326eb12cf99841796fa8(S7bc81a7dfa0975e3e219c94262b1af9b) *) S607e7372580620c5a884262f971fe86a); 
delete((S18fff9cb5ec66ea1b3998c0c6f504bdd(S67d8289f693b177f2a17a6a10106446e) *) S70ffd93d669ae5f2d9833b3fd696a6bf); 
S8542634d1f0eb6829badb2e1f5d42138(Sf1c587725d1d3d625ed5aeb21490ad64);    
#if 0
 if (Sda690b4f1f86a80d09e2b79331302d1f) { for (long S198a6617dc07f3411d5c2ab23837bf26 = 0; S198a6617dc07f3411d5c2ab23837bf26 
< Sdf6f3102050cab47760a9f913c1851a1(S1d8d5e912302108b5e88c3e77fcad378); S198a6617dc07f3411d5c2ab23837bf26++) 
delete(Sda690b4f1f86a80d09e2b79331302d1f[S198a6617dc07f3411d5c2ab23837bf26]); S8542634d1f0eb6829badb2e1f5d42138(Sda690b4f1f86a80d09e2b79331302d1f); 
} if (S490793d90b9f673ca43c5112b6192d9f) { for (unsigned long Sc4755d9c575bce8e3b3bdf338e88ed61 = 0; 
Sc4755d9c575bce8e3b3bdf338e88ed61 < S1d8d5e912302108b5e88c3e77fcad378.Se1493a172a6c69298725b98e4efad119->S2813dab64edada457779d7682be618e2; 
Sc4755d9c575bce8e3b3bdf338e88ed61++) { delete((S7824a773c722026c149f24519969579a *) S490793d90b9f673ca43c5112b6192d9f[Sc4755d9c575bce8e3b3bdf338e88ed61]); 
} S8542634d1f0eb6829badb2e1f5d42138(S490793d90b9f673ca43c5112b6192d9f); } 
#endif
 S8542634d1f0eb6829badb2e1f5d42138(S490793d90b9f673ca43c5112b6192d9f); 
#if defined(macintosh) || defined(HAVE_SSTREAM)
 delete(S6023548ba505b16120eba8594d6d354c); 
#else
 delete(S6023548ba505b16120eba8594d6d354c); Se7a14b9f684496358a78dd4a17d01288(S82302248d41b4cf5ef692a52b1010298); 

#endif
 
#if defined(macintosh) || defined(HAVE_SSTREAM)
 delete(Sebfc0bf878d1f1386b9b4c376187faff); 
#else
 delete(Sebfc0bf878d1f1386b9b4c376187faff); delete(S1d765418a1157e3335b9e0c1cbe13bec); 
#endif
  S8542634d1f0eb6829badb2e1f5d42138(S19e7bc76fe6637a0a36ff6bb2c957096); }

==> sawmill6.4.5_crypt_src.tar.gz: sawmill-6.4.5/Sbfc9cb0c7c2fe6f4e17de2219c571a09.cpp <==
//
// Sawmill Source Code
// 
// This source code is the intellectual property of Flowerfire,
// and is protected by federal trade secret laws.  Do not
// redistribute, modify, or use this source code, except to compile
// it, without the express written consent of Flowerfire.
//
// For more information, see http://www.sawmill.net/trade_secret.html
//
// The trial and full commercial licenses for Sawmill allow you
// to use the program, and to compile it from this source code,
// but you are not permitted to look at this source code.  Please
// do not attempt to use this source code for any purpose other 
// than compilation!



















































 
#include "Sbb7934b786bf92b60599d19b63c794ae.h"

#include "Sbfc9cb0c7c2fe6f4e17de2219c571a09.h"

#include "S02018c21aae4cfd793a8f80f191dec71.h"

#include "S18fff9cb5ec66ea1b3998c0c6f504bdd.h"

#include "Se50f3b1f9b0c326eb12cf99841796fa8.h"

#include "Sa7a50d44af9bffbc03a233a0f926ab33.h"

#include "S34ddd2a7515eccb177b2b41c0576524a.h"

#include "S081ab28a1d97078d41502685d8d23339.h"

#include "Scd1bac794b4941db69a52b57b6ec5f9f.h"

#include "S21d6f40cfb511982e4424e0e250a9557.h"

#include "Sda690b4f1f86a80d09e2b79331302d1f.h"

#include "S502c2d5425ba2c329e58f02e0bf84d5e.h"

#include "Sd72426bef53f59fc97b1772c0f3bf34a.h"

#include "Sfffef868da20c3f5623f11331ac9a581.h"

#include "Sfd40bde7becba15faa6c7faab35e20f0.h"

#include "S4535b1598f7cc738f3c5ab654f23ce06.h"

#include "Sd2dfda25a352b6989f06979d5dca20ff.h"

#include "S5013dc63aece5960aaf85662d6e4defb.h"

#include "Scde0993c6a1124d8ed406bc1a2294738.h"

#include "S3d25fa2cec486988552e0a9ce1a0cb49.h"

#include "S3d52b4397df4d4d0e426da5d85159dbf.h"
 Se812b5a98988bad1d5b8df118cb6cc7f::Se812b5a98988bad1d5b8df118cb6cc7f(Sa374ae40bab87d51f64df15ce1e0bd84 
&S908ea47162d020873e19f62a8278d2d0, S7a8c30ba69067011071ba14cc1b4a63d &S3ecf2642759a04bd3616642bd56bed59) 
: S1d8d5e912302108b5e88c3e77fcad378(S908ea47162d020873e19f62a8278d2d0), S95cc64dd2825f9df13ec4ad683ecf339(S3ecf2642759a04bd3616642bd56bed59) 
{ S9c9188a1eb96d4d80759d212ee813c40 = -1; S08df5d117e6aaeeb23d8c1c0cfc535b8 = false; S7f65873622778583e76793616cc76a1d 
= NULL; S22cbab4815b0c898fc30c34c687fbb9f = false; Se27a65f1feae762e907df741eff89bcc = false; Sf9fbc004dd2b46f967cbb884ef26a5f1 
= 0; Sea0f20f4ee0b8138296f254b6166a9e2 = NULL; S2597f87d2eaac307fffcae4a7696f5e1 = 0;   Sc2cdb780090f037942c0cc62899c60dd 
= false; S90c6813d8aa86264da47e54bfbca12b9 = false; S70efd95bbd5a1637e2b2b03545bc7c97 = 0; Sd81bd76541d72dcc4624a9f668ed831a 
= -1; Sa3ef522750bb6cfebb259b70bc491252 = -1; Saf34297eba0410328ecf05680c3973fb = false; S71e0656cf70f1e0f42713632961f2e83 
= 0; S4e2d4ef7375cc680e7d4a5218cb24910 = 0; Sf33b7605ce39a3959a0a0faafa993648 = false; S5c2b43ac72b401de77771f3d1c229239 
= NULL; Sc0ef64f649a3fb31698c0e34e821ca31 = -1; S611a0faa7adb65cbd3d0744c6b2c0a3d = NULL; Se4060fc9e6cb63b56cee53c62831fc9b 
= NULL; Sc4063383a2f1d9cb2dafa0dfae340d83 = NULL; S893154f4ff2478a68c43298003262505 = false; S42d8701cce0ca1f51d8de5a678eb2261 
= 0; S84a149ab6260fd1dba7b42922161cf76 = false; S53e601e276f9f775fc63e5c2ee651d53 = 0; if (Sa4020546e22fc3be5584817b8fb0246a 
== NULL) { Sa4020546e22fc3be5584817b8fb0246a = this; Sfcc38fa2214c7dad94042741191c53b3 = new S18fff9cb5ec66ea1b3998c0c6f504bdd(Se812b5a98988bad1d5b8df118cb6cc7f 
*); } else { ((S18fff9cb5ec66ea1b3998c0c6f504bdd(Se812b5a98988bad1d5b8df118cb6cc7f *) *) Sa4020546e22fc3be5584817b8fb0246a->Sfcc38fa2214c7dad94042741191c53b3)->push_back(this); 
} S19e7bc76fe6637a0a36ff6bb2c957096 = NULL; S8d8450e5a0709dfcc6a7dcc77e0b6e4e = NULL; S092302eec8db684d8a43e539e32a52b1 
= 0; S7221f6f7a9cab8b731d91ea78e90076f = 0; 
#if defined(macintosh)
 Sebfc0bf878d1f1386b9b4c376187faff = new ostringstream(); 
#else
 S1d765418a1157e3335b9e0c1cbe13bec = new Sf3f2f04ccb90d699288e8cb86ada5e67(cout, *this); Sebfc0bf878d1f1386b9b4c376187faff 
= new S1356d0666866080ee569a8007f7465e0(S1d765418a1157e3335b9e0c1cbe13bec); 
#endif
 
#if defined(macintosh) || defined(HAVE_SSTREAM)
 S6023548ba505b16120eba8594d6d354c = new ostringstream(); 
#else
 S82302248d41b4cf5ef692a52b1010298 = (char *) Sb55824cd22e362581a8a09954133e17b(10000); S6023548ba505b16120eba8594d6d354c 
= new S2d587388d84e669166259e637229a736(S82302248d41b4cf5ef692a52b1010298, 9999); 
#endif
 S279361af4d5ba006aa8688d7736f51f9 = NULL; Scb5e100e5a9a3e7f6d1fd97512215282 = false; S81b63b9d54b303edeaf9765a6915ee13 
= false; S6b2ded51d81a4403d8a4bd25fa1e57ee = false; S40a9622db5a27260c4d5e8f1d354958a = new S18fff9cb5ec66ea1b3998c0c6f504bdd(S7bc81a7dfa0975e3e219c94262b1af9b); 
S607e7372580620c5a884262f971fe86a = new Se50f3b1f9b0c326eb12cf99841796fa8(S82fe905a33b09fbebffca79d483bcd10); 
S154a5d876ee73f9b72430feb6abcf728.Sce5e7ecaa34619ce3cd0f11abbe32bde(*Sa4020546e22fc3be5584817b8fb0246a); 
S0e2413620f3009160a31c65634019d56 = S51a60bde560fadde5d0eb57d9f19c0b1; S51a60bde560fadde5d0eb57d9f19c0b1++; 
S154a5d876ee73f9b72430feb6abcf728.Sb8e7b465df7c5979dc731d06e84ce2cf(*Sa4020546e22fc3be5584817b8fb0246a); 
Sd30ed9ead03f1ac95b8affa1956127ed = NULL; S53e601e276f9f775fc63e5c2ee651d53 = 0; Se1156150b1f690c8f2e2cababc4669a8 
= 0; S284bd53fbfb57ba76bac587c3cf1cd0c = 0; S96e6199a1dfa62795bf64060320f0301 = 0; Sfc77f9ae4de2e002f5b72de5dfa577a0(*this); 
Se812b5a98988bad1d5b8df118cb6cc7f &S4d682ec4eed27c53849758bc13b6e179 = *this; S2b91dc4462409a9f0466da680eeadb23 
= 50000; Saf6c0c3c714d1f5ab0d299b2cbf50060(Sf1c587725d1d3d625ed5aeb21490ad64 = (char *) S69d014b769e6f390ab59e42ff5dc9571(S2b91dc4462409a9f0466da680eeadb23, 
"initializing token buffer"));   for (int S865c0c0b4ab0e063e5caa3387c1a8741 = 0; S865c0c0b4ab0e063e5caa3387c1a8741 
< 20; S865c0c0b4ab0e063e5caa3387c1a8741++) Sf1c587725d1d3d625ed5aeb21490ad64[S865c0c0b4ab0e063e5caa3387c1a8741] 
= '0'; S3bd31e1db9c41752857ea3dc8b544da5 = NULL; S45bb047ee77be91f951755654fd1cf64 = 0; S490793d90b9f673ca43c5112b6192d9f 
= NULL; Sda690b4f1f86a80d09e2b79331302d1f = NULL; S70ffd93d669ae5f2d9833b3fd696a6bf = new S18fff9cb5ec66ea1b3998c0c6f504bdd(S67d8289f693b177f2a17a6a10106446e); 
S63f7a20c869ab49b1256d73134c51bd8 = NULL; Se9594a2849d3fbc85b7e13386d03c748 = 0; Sa292896a8834f680d0d7910415cfe6aa 
= 0; Sc99faa22803997c264dbf7ec274f626d = 0; S6edff6f9acd6531aba7bf7f6bcf4ebc6 = 0; S6f49c06ecf096f650296b2f597ad7b9d 
= NULL; Sd6c9f1d753edb49ab3b2ce89228f859d = NULL; Sca788bb10eb1084eeb70fe3f9f41ac96 = NULL; S5b17d3bd4a598d71b357f5aba0e56a69 
= 0; Sb3ed21678a76749fa2af40ab56453ac6 = NULL; Se255569260fe9e8f5f75e5f36f1c8244 = false; S700633a1b0f65fa8456a18bd6053193c 
= false; Sb814a6cb84002cd6a8b2ae1c5d3e095b = false; Sa513a681cb9ab5c94d50cd28d932b51c = false; }  Se812b5a98988bad1d5b8df118cb6cc7f::~Se812b5a98988bad1d5b8df118cb6cc7f(void) 
{ if (Sc4063383a2f1d9cb2dafa0dfae340d83) { Sc4063383a2f1d9cb2dafa0dfae340d83->S0f42007614120ad55ee822b263a2982b(*this); 
delete(Sc4063383a2f1d9cb2dafa0dfae340d83); } if (Se4060fc9e6cb63b56cee53c62831fc9b) delete(Se4060fc9e6cb63b56cee53c62831fc9b); 
delete(Sea0f20f4ee0b8138296f254b6166a9e2); S8542634d1f0eb6829badb2e1f5d42138(Sb3ed21678a76749fa2af40ab56453ac6); 
for (S18fff9cb5ec66ea1b3998c0c6f504bdd(Se812b5a98988bad1d5b8df118cb6cc7f *)::iterator Sd895ed90bab5a86173ead3a829e26d10 
= ((S18fff9cb5ec66ea1b3998c0c6f504bdd(Se812b5a98988bad1d5b8df118cb6cc7f *) *) Sa4020546e22fc3be5584817b8fb0246a->Sfcc38fa2214c7dad94042741191c53b3)->begin(); 
Sd895ed90bab5a86173ead3a829e26d10 != ((S18fff9cb5ec66ea1b3998c0c6f504bdd(Se812b5a98988bad1d5b8df118cb6cc7f 
*) *) Sa4020546e22fc3be5584817b8fb0246a->Sfcc38fa2214c7dad94042741191c53b3)->end(); Sd895ed90bab5a86173ead3a829e26d10++) 
{ if (*Sd895ed90bab5a86173ead3a829e26d10 == this) { ((S18fff9cb5ec66ea1b3998c0c6f504bdd(Se812b5a98988bad1d5b8df118cb6cc7f 
*) *) Sa4020546e22fc3be5584817b8fb0246a->Sfcc38fa2214c7dad94042741191c53b3)->erase(Sd895ed90bab5a86173ead3a829e26d10); 
break; } } S8542634d1f0eb6829badb2e1f5d42138(S8d8450e5a0709dfcc6a7dcc77e0b6e4e); for (unsigned long 
S2fbe9ae4fdee1fc17b970499d596fd7b = 0; (long) S2fbe9ae4fdee1fc17b970499d596fd7b < Sc0ef64f649a3fb31698c0e34e821ca31 
+ 1; S2fbe9ae4fdee1fc17b970499d596fd7b ++ ) { S88c189a42c87aa49d667fc8ab76bc323(S5c2b43ac72b401de77771f3d1c229239[S2fbe9ae4fdee1fc17b970499d596fd7b]); 
} Sc0ef64f649a3fb31698c0e34e821ca31 = 0; S88c189a42c87aa49d667fc8ab76bc323(S5c2b43ac72b401de77771f3d1c229239); 
S88c189a42c87aa49d667fc8ab76bc323(S611a0faa7adb65cbd3d0744c6b2c0a3d); delete(Sd6c9f1d753edb49ab3b2ce89228f859d); 
if (S6f49c06ecf096f650296b2f597ad7b9d) delete[] (regmatch_t *) S6f49c06ecf096f650296b2f597ad7b9d; S99641eea54137181f34c9f030edd808e(*this); 
delete((S18fff9cb5ec66ea1b3998c0c6f504bdd(S7bc81a7dfa0975e3e219c94262b1af9b) *) S40a9622db5a27260c4d5e8f1d354958a); 
delete((Se50f3b1f9b0c326eb12cf99841796fa8(S7bc81a7dfa0975e3e219c94262b1af9b) *) S607e7372580620c5a884262f971fe86a); 
delete((S18fff9cb5ec66ea1b3998c0c6f504bdd(S67d8289f693b177f2a17a6a10106446e) *) S70ffd93d669ae5f2d9833b3fd696a6bf); 
S8542634d1f0eb6829badb2e1f5d42138(Sf1c587725d1d3d625ed5aeb21490ad64);    
#if 0
 if (Sda690b4f1f86a80d09e2b79331302d1f) { for (long S198a6617dc07f3411d5c2ab23837bf26 = 0; S198a6617dc07f3411d5c2ab23837bf26 
< Sdf6f3102050cab47760a9f913c1851a1(S1d8d5e912302108b5e88c3e77fcad378); S198a6617dc07f3411d5c2ab23837bf26++) 
delete(Sda690b4f1f86a80d09e2b79331302d1f[S198a6617dc07f3411d5c2ab23837bf26]); S8542634d1f0eb6829badb2e1f5d42138(Sda690b4f1f86a80d09e2b79331302d1f); 
} if (S490793d90b9f673ca43c5112b6192d9f) { for (unsigned long Sc4755d9c575bce8e3b3bdf338e88ed61 = 0; 
Sc4755d9c575bce8e3b3bdf338e88ed61 < S1d8d5e912302108b5e88c3e77fcad378.Se1493a172a6c69298725b98e4efad119->S2813dab64edada457779d7682be618e2; 
Sc4755d9c575bce8e3b3bdf338e88ed61++) { delete((S7824a773c722026c149f24519969579a *) S490793d90b9f673ca43c5112b6192d9f[Sc4755d9c575bce8e3b3bdf338e88ed61]); 
} S8542634d1f0eb6829badb2e1f5d42138(S490793d90b9f673ca43c5112b6192d9f); } 
#endif
 S8542634d1f0eb6829badb2e1f5d42138(S490793d90b9f673ca43c5112b6192d9f); 
#if defined(macintosh) || defined(HAVE_SSTREAM)
 delete((ostringstream *) S6023548ba505b16120eba8594d6d354c); 
#else
 delete(S6023548ba505b16120eba8594d6d354c); Se7a14b9f684496358a78dd4a17d01288((S2d587388d84e669166259e637229a736 
*) S82302248d41b4cf5ef692a52b1010298); 
#endif
 
#if defined(macintosh) || defined(HAVE_SSTREAM)
 delete(Sebfc0bf878d1f1386b9b4c376187faff); 
#else
 delete(Sebfc0bf878d1f1386b9b4c376187faff); delete(S1d765418a1157e3335b9e0c1cbe13bec); 
#endif
  S8542634d1f0eb6829badb2e1f5d42138(S19e7bc76fe6637a0a36ff6bb2c957096); }
